
/*  qsort.c  Testroutine for qsort() function by C.W.Kessler 03/95 */

#include <fork.h>
#include <stdlib.h>
#include <syscall.h>
#include <io.h>

extern void output_array( int*, int );

sh int n = 200;

int compare( void *A, void *B) 
{
  register int a = (*(int *)A);
  register int b = (*(int *)B);
  /* prS("compare:"); prI(a,0);prS(" "); prIln(b); */
  if (a<b) return -1;
  if (a==b) return 0;
  if (a>b) return 1;
}


void main( void ) 
{
 pr int i;
 start {
   sh int *a;
   a = (int *) shalloc(n);
   farm srand( 1234567 );
   /* preset the input array: */
   farm if ($==0) {
      prS("\nUnsorted Array:\n");
      for (i=0; i<n; i++)  a[i] = rand(); 
      output_array( a, n );                  /*print the original array*/
      qsort( &(a[0]), n, 1, compare );
      prS("\nSorted Array:\n");
      output_array( a, n );                  /*print the resulting array*/
   }
 }
}


void output_array( int *arr, int n )
{
  pr int i;
  for (i=0; i<n; i++)
       { prI( arr[i],0 ); write(1," ",1); }
  write(1,"\n\n",2);
}
